"""The logs command."""


from json import dumps

from .base import Base

import os, subprocess


class Fix(Base):
    """Docker logs"""

    def run(self):
        output = subprocess.Popen(['git', 'status'], stdout=subprocess.PIPE);
        print(output.stdout)


"""The logs command."""


from json import dumps

from .base import Base

import os


class Build(Base):
    """Say hello, world!"""

    def run(self):
        java_path = os.path.join(self.path, "java")
        php_path = os.path.join(self.path, "php")

        os.system("docker-compose stop")
        if self.options["-c"]:
            os.chdir(java_path)
            os.system("docker rm api_changelog_1")
            os.system("docker rmi java/changelog")
            os.system("./gradlew changelog:distDocker")
        if self.options["-m"]:
            os.chdir(java_path)
            os.system("docker rm api_migrations_1")
            os.system("docker rmi java/migrations")
            os.system("./gradlew migrations:clean")
            os.system("./gradlew migrations:jar")
            os.system("./gradlew migrations:distDocker")
        if self.options["-s"]:
            os.chdir(java_path)
            os.system("docker rm api_mysql_1")
        if self.options["-r"]:
            os.chdir(java_path)
            os.system("docker rm api_rcash_1")
            os.system("docker rmi java/rcash")
            os.system("./gradlew rcash:distDocker")
        if self.options["-e"]:
            os.chdir(java_path)
            os.system("docker rm api_email_1")
            os.system("docker rmi java/email")
            os.system("./gradlew email:distDocker")
        if self.options["-a"]:
            os.chdir(php_path)
            os.system("docker build -t hb_api .")
        if self.options["-x"]:
            os.chdir(php_path)
            os.system("docker build --no-cache -t hb_api .")

        os.system("docker-compose up -d");


"""Packaging settings."""


from codecs import open
from os.path import abspath, dirname, join
from subprocess import call

from setuptools import Command, find_packages, setup

from xudo import __version__


this_dir = abspath(dirname(__file__))
with open(join(this_dir, 'README.rst'), encoding='utf-8') as file:
    long_description = file.read()

class RunTests(Command):
    """Run all tests."""
    description = 'run tests'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        """Run all tests!"""
        errno = call(['py.test', '--cov=xudo', '--cov-report=term-missing'])
        raise SystemExit(errno)


setup(
    name = 'xudo',
    version = __version__,
    description = 'A command line program for docker',
    long_description = long_description,
    url = 'https://github.com/ostralyan/xudo-cli',
    author = 'Luke Xu',
    author_email = 'lukecxu@gmail.com',
    license = 'MIT License',
    classifiers = [
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: Public Domain',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords = 'cli',
    packages = find_packages(exclude=['docs', 'tests*']),
    install_requires = ['docopt', 'requests'],
    extras_require = {
        'test': ['coverage', 'pytest', 'pytest-cov'],
    },
    entry_points = {
        'console_scripts': [
            'xudo=xudo.cli:main',
        ],
    },
    cmdclass = {'test': RunTests},
)